==> nautobot_data_validation_engine-2.2.0.tar.gz: nautobot_data_validation_engine-2.2.0/nautobot_data_validation_engine/tests/test_filters.py <==
"""
Filterset test cases
"""
from django.contrib.contenttypes.models import ContentType
from nautobot.utilities.testing.filters import FilterTestCases

from nautobot.dcim.models import PowerFeed, Rack, Region, Site, Platform, Manufacturer

from nautobot_data_validation_engine.filters import (
    MinMaxValidationRuleFilterSet,
    RegularExpressionValidationRuleFilterSet,
    RequiredValidationRuleFilterSet,
    UniqueValidationRuleFilterSet,
)
from nautobot_data_validation_engine.models import (
    MinMaxValidationRule,
    RegularExpressionValidationRule,
    RequiredValidationRule,
    UniqueValidationRule,
)


class RegularExpressionValidationRuleFilterTestCase(FilterTestCases.NameSlugFilterTestCase):
    """
    Filterset test cases for the RegularExpressionValidationRule model
    """

    queryset = RegularExpressionValidationRule.objects.all()
    filterset = RegularExpressionValidationRuleFilterSet

    @classmethod
    def setUpTestData(cls):
        """
        Create test data
        """
        RegularExpressionValidationRule.objects.create(
            name="Regex rule 1",
            slug="regex-rule-1",
            content_type=ContentType.objects.get_for_model(Rack),
            field="name",
            regular_expression="^ABC$",
            error_message="A",
        )
        RegularExpressionValidationRule.objects.create(
            name="Regex rule 2",
            slug="regex-rule-2",
            content_type=ContentType.objects.get_for_model(Region),
            field="description",
            regular_expression="DEF$",
            error_message="B",
        )
        RegularExpressionValidationRule.objects.create(
            name="Regex rule 3",
            slug="regex-rule-3",
            content_type=ContentType.objects.get_for_model(Site),
            field="comments",
            regular_expression="GHI",
            error_message="C",
        )

    def test_id(self):
        """Test ID lookups."""
        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_content_type(self):
        """Test content type lookups."""
        params = {"content_type": ["dcim.rack", "dcim.site"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_regular_expression(self):
        """Test regex lookups."""
        # TODO(john): revisit this once this is sorted: https://github.com/nautobot/nautobot/issues/477
        params = {"regular_expression": "^ABC$"}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)

    def test_error_message(self):
        """Test error message lookups."""
        params = {"error_message": ["A", "B"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_field(self):
        """Test field lookups."""
        params = {"field": ["name", "description"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)


class MinMaxValidationRuleFilterTestCase(FilterTestCases.NameSlugFilterTestCase):
    """
    Filterset test cases for the MinMaxValidationRule model
    """

    queryset = MinMaxValidationRule.objects.all()
    filterset = MinMaxValidationRuleFilterSet

    @classmethod
    def setUpTestData(cls):
        """
        Create test data
        """
        MinMaxValidationRule.objects.create(
            name="Min max rule 1",
            slug="min-max-rule-1",
            content_type=ContentType.objects.get_for_model(PowerFeed),
            field="amperage",
            min=1,
            error_message="A",
        )
        MinMaxValidationRule.objects.create(
            name="Min max rule 2",
            slug="min-max-rule-2",
            content_type=ContentType.objects.get_for_model(PowerFeed),
            field="max_utilization",
            min=1,
            error_message="B",
        )
        MinMaxValidationRule.objects.create(
            name="Min max rule 3",
            slug="min-max-rule-3",
            content_type=ContentType.objects.get_for_model(PowerFeed),
            field="voltage",
            min=1,
            error_message="C",
        )

    def test_id(self):
        """Test ID lookups."""
        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_content_type(self):
        """Test content type lookups."""
        params = {"content_type": ["dcim.powerfeed"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)

    def test_error_message(self):
        """Test error message lookups."""
        params = {"error_message": ["A", "B"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_field(self):
        """Test field lookups."""
        params = {"field": ["voltage", "max_utilization"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)


class RequiredValidationRuleFilterTestCase(FilterTestCases.NameSlugFilterTestCase):
    """
    Filterset test cases for the RequiredValidationRule model
    """

    queryset = RequiredValidationRule.objects.all()
    filterset = RequiredValidationRuleFilterSet

    @classmethod
    def setUpTestData(cls):
        """
        Create test data
        """
        RequiredValidationRule.objects.create(
            name="Required rule 1",
            slug="required-rule-1",
            content_type=ContentType.objects.get_for_model(Site),
            field="asn",
            error_message="A",
        )
        RequiredValidationRule.objects.create(
            name="Required rule 2",
            slug="required-rule-2",
            content_type=ContentType.objects.get_for_model(Platform),
            field="description",
            error_message="B",
        )
        RequiredValidationRule.objects.create(
            name="Required rule 3",
            slug="required-rule-3",
            content_type=ContentType.objects.get_for_model(Manufacturer),
            field="description",
            error_message="C",
        )

    def test_id(self):
        """Test ID lookups."""
        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_content_type(self):
        """Test content type lookups."""
        params = {"content_type": ["dcim.site"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)

    def test_error_message(self):
        """Test error message lookups."""
        params = {"error_message": ["A", "B"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_field(self):
        """Test field lookups."""
        params = {"field": ["asn"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)


class UniqueValidationRuleFilterTestCase(FilterTestCases.NameSlugFilterTestCase):
    """
    Filterset test cases for the UniqueValidationRule model
    """

    queryset = UniqueValidationRule.objects.all()
    filterset = UniqueValidationRuleFilterSet

    @classmethod
    def setUpTestData(cls):
        """
        Create test data
        """
        UniqueValidationRule.objects.create(
            name="Unique rule 1",
            slug="unique-rule-1",
            content_type=ContentType.objects.get_for_model(Site),
            field="asn",
            max_instances=1,
            error_message="A",
        )
        UniqueValidationRule.objects.create(
            name="Unique rule 2",
            slug="unique-rule-2",
            content_type=ContentType.objects.get_for_model(Platform),
            field="description",
            max_instances=2,
            error_message="B",
        )
        UniqueValidationRule.objects.create(
            name="Unique rule 3",
            slug="unique-rule-3",
            content_type=ContentType.objects.get_for_model(Manufacturer),
            field="description",
            max_instances=3,
            error_message="C",
        )

    def test_id(self):
        """Test ID lookups."""
        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_content_type(self):
        """Test content type lookups."""
        params = {"content_type": ["dcim.site"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)

    def test_error_message(self):
        """Test error message lookups."""
        params = {"error_message": ["A", "B"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_field(self):
        """Test field lookups."""
        params = {"field": ["asn"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)

    def test_max_instances(self):
        """Test field lookups."""
        params = {"max_instances__gte": [2]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

==> nautobot_data_validation_engine-3.0.1.tar.gz: nautobot_data_validation_engine-3.0.1/nautobot_data_validation_engine/tests/test_filters.py <==
"""
Filterset test cases
"""
from django.contrib.contenttypes.models import ContentType

from nautobot.core.testing.filters import FilterTestCases
from nautobot.dcim.models import Location, Manufacturer, Platform, PowerFeed, Rack
from nautobot.extras.models import Tag

from nautobot_data_validation_engine.filters import (
    MinMaxValidationRuleFilterSet,
    RegularExpressionValidationRuleFilterSet,
    RequiredValidationRuleFilterSet,
    UniqueValidationRuleFilterSet,
)
from nautobot_data_validation_engine.models import (
    MinMaxValidationRule,
    RegularExpressionValidationRule,
    RequiredValidationRule,
    UniqueValidationRule,
)


class RegularExpressionValidationRuleFilterTestCase(FilterTestCases.NameOnlyFilterTestCase):
    """
    Filterset test cases for the RegularExpressionValidationRule model
    """

    queryset = RegularExpressionValidationRule.objects.all()
    filterset = RegularExpressionValidationRuleFilterSet

    @classmethod
    def setUpTestData(cls):
        """
        Create test data
        """
        tag_1 = Tag.objects.create(
            name="Tag 1",
            color="00bcd4",
            description="Test tag 1",
        )
        tag_1.content_types.set([ContentType.objects.get_for_model(RegularExpressionValidationRule)])
        tag_2 = Tag.objects.create(
            name="Tag 2",
            color="ff5722",
            description="Test tag 2",
        )
        tag_2.content_types.set([ContentType.objects.get_for_model(RegularExpressionValidationRule)])
        regex_1 = RegularExpressionValidationRule.objects.create(
            name="Regex rule 1",
            content_type=ContentType.objects.get_for_model(Rack),
            field="name",
            regular_expression="^ABC$",
            error_message="A",
        )
        regex_1.tags.set([tag_1, tag_2])
        RegularExpressionValidationRule.objects.create(
            name="Regex rule 2",
            content_type=ContentType.objects.get_for_model(Location),
            field="description",
            regular_expression="DEF$",
            error_message="B",
        )
        RegularExpressionValidationRule.objects.create(
            name="Regex rule 3",
            content_type=ContentType.objects.get_for_model(Location),
            field="comments",
            regular_expression="GHI",
            error_message="C",
        )

    def test_id(self):
        """Test ID lookups."""
        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_content_type(self):
        """Test content type lookups."""
        params = {"content_type": ["dcim.rack", "dcim.location"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)

    def test_regular_expression(self):
        """Test regex lookups."""
        # TODO(john): revisit this once this is sorted: https://github.com/nautobot/nautobot/issues/477
        params = {"regular_expression": "^ABC$"}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)

    def test_error_message(self):
        """Test error message lookups."""
        params = {"error_message": ["A", "B"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_field(self):
        """Test field lookups."""
        params = {"field": ["name", "description"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)


class MinMaxValidationRuleFilterTestCase(FilterTestCases.NameOnlyFilterTestCase):
    """
    Filterset test cases for the MinMaxValidationRule model
    """

    queryset = MinMaxValidationRule.objects.all()
    filterset = MinMaxValidationRuleFilterSet

    @classmethod
    def setUpTestData(cls):
        """
        Create test data
        """
        tag_1 = Tag.objects.create(
            name="Tag 1",
            color="00bcd4",
            description="Test tag 1",
        )
        tag_1.content_types.set([ContentType.objects.get_for_model(MinMaxValidationRule)])
        tag_2 = Tag.objects.create(
            name="Tag 2",
            color="ff5722",
            description="Test tag 2",
        )
        tag_2.content_types.set([ContentType.objects.get_for_model(MinMaxValidationRule)])
        min_max_1 = MinMaxValidationRule.objects.create(
            name="Min max rule 1",
            content_type=ContentType.objects.get_for_model(PowerFeed),
            field="amperage",
            min=1,
            error_message="A",
        )
        min_max_1.tags.set([tag_1, tag_2])
        MinMaxValidationRule.objects.create(
            name="Min max rule 2",
            content_type=ContentType.objects.get_for_model(PowerFeed),
            field="max_utilization",
            min=1,
            error_message="B",
        )
        MinMaxValidationRule.objects.create(
            name="Min max rule 3",
            content_type=ContentType.objects.get_for_model(PowerFeed),
            field="voltage",
            min=1,
            error_message="C",
        )

    def test_id(self):
        """Test ID lookups."""
        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_content_type(self):
        """Test content type lookups."""
        params = {"content_type": ["dcim.powerfeed"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)

    def test_error_message(self):
        """Test error message lookups."""
        params = {"error_message": ["A", "B"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_field(self):
        """Test field lookups."""
        params = {"field": ["voltage", "max_utilization"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)


class RequiredValidationRuleFilterTestCase(FilterTestCases.NameOnlyFilterTestCase):
    """
    Filterset test cases for the RequiredValidationRule model
    """

    queryset = RequiredValidationRule.objects.all()
    filterset = RequiredValidationRuleFilterSet

    @classmethod
    def setUpTestData(cls):
        """
        Create test data
        """
        tag_1 = Tag.objects.create(
            name="Tag 1",
            color="00bcd4",
            description="Test tag 1",
        )
        tag_1.content_types.set([ContentType.objects.get_for_model(RequiredValidationRule)])
        tag_2 = Tag.objects.create(
            name="Tag 2",
            color="ff5722",
            description="Test tag 2",
        )
        tag_2.content_types.set([ContentType.objects.get_for_model(RequiredValidationRule)])
        required_1 = RequiredValidationRule.objects.create(
            name="Required rule 1",
            content_type=ContentType.objects.get_for_model(Location),
            field="asn",
            error_message="A",
        )
        required_1.tags.set([tag_1, tag_2])
        RequiredValidationRule.objects.create(
            name="Required rule 2",
            content_type=ContentType.objects.get_for_model(Platform),
            field="description",
            error_message="B",
        )
        RequiredValidationRule.objects.create(
            name="Required rule 3",
            content_type=ContentType.objects.get_for_model(Manufacturer),
            field="description",
            error_message="C",
        )

    def test_id(self):
        """Test ID lookups."""
        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_content_type(self):
        """Test content type lookups."""
        params = {"content_type": ["dcim.location"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)

    def test_error_message(self):
        """Test error message lookups."""
        params = {"error_message": ["A", "B"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_field(self):
        """Test field lookups."""
        params = {"field": ["asn"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)


class UniqueValidationRuleFilterTestCase(FilterTestCases.NameOnlyFilterTestCase):
    """
    Filterset test cases for the UniqueValidationRule model
    """

    queryset = UniqueValidationRule.objects.all()
    filterset = UniqueValidationRuleFilterSet

    @classmethod
    def setUpTestData(cls):
        """
        Create test data
        """
        tag_1 = Tag.objects.create(
            name="Tag 1",
            color="00bcd4",
            description="Test tag 1",
        )
        tag_1.content_types.set([ContentType.objects.get_for_model(UniqueValidationRule)])
        tag_2 = Tag.objects.create(
            name="Tag 2",
            color="ff5722",
            description="Test tag 2",
        )
        tag_2.content_types.set([ContentType.objects.get_for_model(UniqueValidationRule)])
        unique_1 = UniqueValidationRule.objects.create(
            name="Unique rule 1",
            content_type=ContentType.objects.get_for_model(Location),
            field="asn",
            max_instances=1,
            error_message="A",
        )
        unique_1.tags.set([tag_1, tag_2])
        UniqueValidationRule.objects.create(
            name="Unique rule 2",
            content_type=ContentType.objects.get_for_model(Platform),
            field="description",
            max_instances=2,
            error_message="B",
        )
        UniqueValidationRule.objects.create(
            name="Unique rule 3",
            content_type=ContentType.objects.get_for_model(Manufacturer),
            field="description",
            max_instances=3,
            error_message="C",
        )

    def test_id(self):
        """Test ID lookups."""
        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_content_type(self):
        """Test content type lookups."""
        params = {"content_type": ["dcim.location"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)

    def test_error_message(self):
        """Test error message lookups."""
        params = {"error_message": ["A", "B"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)

    def test_field(self):
        """Test field lookups."""
        params = {"field": ["asn"]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)

    def test_max_instances(self):
        """Test field lookups."""
        params = {"max_instances__gte": [2]}
        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
